==> flink-1.20.3-src.tgz: flink-1.20.3/flink-core-api/src/main/java/org/apache/flink/api/common/state/v2/AggregatingState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.state.v2;

import org.apache.flink.annotation.Experimental;

/**
 * {@link State} interface for aggregating state, based on an {@link
 * org.apache.flink.api.common.functions.AggregateFunction}. Elements that are added to this type of
 * state will be eagerly pre-aggregated using a given {@code AggregateFunction}.
 *
 * <p>The state holds internally always the accumulator type of the {@code AggregateFunction}. When
 * accessing the result of the state, the function's {@link
 * org.apache.flink.api.common.functions.AggregateFunction#getResult(Object)} method.
 *
 * <p>The state is accessed and modified by user functions, and checkpointed consistently by the
 * system as part of the distributed snapshots.
 *
 * <p>The state is only accessible by functions applied on a {@code KeyedStream}. The key is
 * automatically supplied by the system, so the function always sees the value mapped to the key of
 * the current element. That way, the system can handle stream and state partitioning consistently
 * together.
 *
 * @param <IN> Type of the value added to the state.
 * @param <OUT> Type of the value extracted from the state.
 */
@Experimental
public interface AggregatingState<IN, OUT> extends MergingState<IN, OUT> {}

==> flink-2.2.0-src.tgz: flink-2.2.0/flink-core-api/src/main/java/org/apache/flink/api/common/state/v2/AggregatingState.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.state.v2;

import org.apache.flink.annotation.Experimental;

/**
 * {@link State} interface for aggregating state, based on an {@link
 * org.apache.flink.api.common.functions.AggregateFunction}. Elements that are added to this type of
 * state will be eagerly pre-aggregated using a given {@code AggregateFunction}.
 *
 * <p>The state holds internally always the accumulator type of the {@code AggregateFunction}. When
 * accessing the result of the state, the function's {@link
 * org.apache.flink.api.common.functions.AggregateFunction#getResult(Object)} method.
 *
 * <p>The state is accessed and modified by user functions, and checkpointed consistently by the
 * system as part of the distributed snapshots.
 *
 * <p>The state is only accessible by functions applied on a {@code KeyedStream}. The key is
 * automatically supplied by the system, so the function always sees the value mapped to the key of
 * the current element. That way, the system can handle stream and state partitioning consistently
 * together.
 *
 * @param <IN> Type of the value added to the state.
 * @param <OUT> Type of the value extracted from the state.
 */
@Experimental
public interface AggregatingState<IN, OUT> extends MergingState<IN, OUT, OUT> {}
